@@ -23,9 +23,11 @@ import java.io.Serializable;
 import java.io.StringWriter;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.ListIterator;
 import java.util.Map;
 
 /**
@@ -44,10 +46,13 @@ public class Xpp3Dom
 
     protected final List<Xpp3Dom> childList;
 
-    protected final Map<String, Xpp3Dom> childMap;
-
     protected Xpp3Dom parent;
 
+    /**
+     * @since 3.2.0
+     */
+    protected Object inputLocation;
+
     private static final String[] EMPTY_STRING_ARRAY = new String[0];
 
     private static final Xpp3Dom[] EMPTY_DOM_ARRAY = new Xpp3Dom[0];
@@ -83,7 +88,15 @@ public class Xpp3Dom
     {
         this.name = name;
         childList = new ArrayList<Xpp3Dom>();
-        childMap = new HashMap<String, Xpp3Dom>();
+    }
+
+    /**
+     * @since 3.2.0
+     */
+    public Xpp3Dom( String name, Object inputLocation )
+    {
+        this( name );
+        this.inputLocation = inputLocation;
     }
 
     /**
@@ -100,11 +113,11 @@ public class Xpp3Dom
     public Xpp3Dom( Xpp3Dom src, String name )
     {
         this.name = name;
+        this.inputLocation = src.inputLocation;
 
         int childCount = src.getChildCount();
 
         childList = new ArrayList<Xpp3Dom>( childCount );
-        childMap = new HashMap<String, Xpp3Dom>( childCount << 1 );
 
         setValue( src.getValue() );
 
@@ -155,13 +168,13 @@ public class Xpp3Dom
         }
         else
         {
-            return (String[]) attributes.keySet().toArray( new String[attributes.size()] );
+            return attributes.keySet().toArray( EMPTY_STRING_ARRAY );
         }
     }
 
     public String getAttribute( String name )
     {
-        return ( null != attributes ) ? (String) attributes.get( name ) : null;
+        return ( null != attributes ) ? attributes.get( name ) : null;
     }
 
     /**
@@ -194,19 +207,30 @@ public class Xpp3Dom
 
     public Xpp3Dom getChild( int i )
     {
-        return (Xpp3Dom) childList.get( i );
+        return childList.get( i );
     }
 
     public Xpp3Dom getChild( String name )
     {
-        return (Xpp3Dom) childMap.get( name );
+        if ( name != null )
+        {
+            ListIterator<Xpp3Dom> it = childList.listIterator( childList.size() );
+            while ( it.hasPrevious() )
+            {
+                Xpp3Dom child = it.previous();
+                if ( name.equals( child.getName() ) )
+                {
+                    return child;
+                }
+            }
+        }
+        return null;
     }
 
     public void addChild( Xpp3Dom xpp3Dom )
     {
         xpp3Dom.setParent( this );
         childList.add( xpp3Dom );
-        childMap.put( xpp3Dom.getName(), xpp3Dom );
     }
 
     public Xpp3Dom[] getChildren()
@@ -217,31 +241,45 @@ public class Xpp3Dom
         }
         else
         {
-            return (Xpp3Dom[]) childList.toArray( new Xpp3Dom[childList.size()] );
+            return childList.toArray( EMPTY_DOM_ARRAY );
         }
     }
 
     public Xpp3Dom[] getChildren( String name )
+    {
+        return getChildrenAsList( name ).toArray( EMPTY_DOM_ARRAY );
+    }
+
+    private List<Xpp3Dom> getChildrenAsList( String name )
     {
         if ( null == childList )
         {
-            return EMPTY_DOM_ARRAY;
+            return Collections.emptyList();
         }
         else
         {
-            ArrayList<Xpp3Dom> children = new ArrayList<Xpp3Dom>();
-            int size = childList.size();
+            ArrayList<Xpp3Dom> children = null;
 
-            for ( Xpp3Dom aChildList : childList )
+            for ( Xpp3Dom configuration : childList )
             {
-                Xpp3Dom configuration = (Xpp3Dom) aChildList;
                 if ( name.equals( configuration.getName() ) )
                 {
+                    if ( children == null )
+                    {
+                        children = new ArrayList<Xpp3Dom>();
+                    }
                     children.add( configuration );
                 }
             }
 
-            return (Xpp3Dom[]) children.toArray( new Xpp3Dom[children.size()] );
+            if ( children != null )
+            {
+                return children;
+            }
+            else
+            {
+                return Collections.emptyList();
+            }
         }
     }
 
@@ -258,7 +296,6 @@ public class Xpp3Dom
     public void removeChild( int i )
     {
         Xpp3Dom child = getChild( i );
-        childMap.values().remove( child );
         childList.remove( i );
         // In case of any dangling references
         child.setParent( null );
@@ -278,6 +315,26 @@ public class Xpp3Dom
         this.parent = parent;
     }
 
+    // ----------------------------------------------------------------------
+    // Input location handling
+    // ----------------------------------------------------------------------
+
+    /**
+     * @since 3.2.0
+     */
+    public Object getInputLocation()
+    {
+        return inputLocation;
+    }
+
+    /**
+     * @since 3.2.0
+     */
+    public void setInputLocation( Object inputLocation )
+    {
+        this.inputLocation = inputLocation;
+    }
+
     // ----------------------------------------------------------------------
     // Helpers
     // ----------------------------------------------------------------------
@@ -296,23 +353,41 @@ public class Xpp3Dom
     }
 
     /**
-     * Merges one DOM into another, given a specific algorithm and possible override points for that algorithm. The
-     * algorithm is as follows: 1. if the recessive DOM is null, there is nothing to do...return. 2. Determine whether
-     * the dominant node will suppress the recessive one (flag=mergeSelf). A. retrieve the 'combine.self' attribute on
-     * the dominant node, and try to match against 'override'... if it matches 'override', then set mergeSelf ==
-     * false...the dominant node suppresses the recessive one completely. B. otherwise, use the default value for
-     * mergeSelf, which is true...this is the same as specifying 'combine.self' == 'merge' as an attribute of the
-     * dominant root node. 3. If mergeSelf == true A. if the dominant root node's value is empty, set it to the
-     * recessive root node's value B. For each attribute in the recessive root node which is not set in the dominant
-     * root node, set it. C. Determine whether children from the recessive DOM will be merged or appended to the
-     * dominant DOM as siblings (flag=mergeChildren). i. if childMergeOverride is set (non-null), use that value
-     * (true/false) ii. retrieve the 'combine.children' attribute on the dominant node, and try to match against
-     * 'append'...if it matches 'append', then set mergeChildren == false...the recessive children will be appended as
-     * siblings of the dominant children. iii. otherwise, use the default value for mergeChildren, which is true...this
-     * is the same as specifying 'combine.children' == 'merge' as an attribute on the dominant root node. D. Iterate
-     * through the recessive children, and: i. if mergeChildren == true and there is a corresponding dominant child
-     * (matched by element name), merge the two. ii. otherwise, add the recessive child as a new child on the dominant
-     * root node.
+     * Merges one DOM into another, given a specific algorithm and possible override points for that algorithm.<p>
+     * The algorithm is as follows:
+     * <ol>
+     * <li> if the recessive DOM is null, there is nothing to do... return.</li>
+     * <li> Determine whether the dominant node will suppress the recessive one (flag=mergeSelf).
+     *   <ol type="A">
+     *   <li> retrieve the 'combine.self' attribute on the dominant node, and try to match against 'override'...
+     *        if it matches 'override', then set mergeSelf == false...the dominant node suppresses the recessive one
+     *        completely.</li>
+     *   <li> otherwise, use the default value for mergeSelf, which is true...this is the same as specifying
+     *        'combine.self' == 'merge' as an attribute of the dominant root node.</li>
+     *   </ol></li>
+     * <li> If mergeSelf == true
+     *   <ol type="A">
+     *   <li> if the dominant root node's value is empty, set it to the recessive root node's value</li>
+     *   <li> For each attribute in the recessive root node which is not set in the dominant root node, set it.</li>
+     *   <li> Determine whether children from the recessive DOM will be merged or appended to the dominant DOM as
+     *        siblings (flag=mergeChildren).
+     *     <ol type="i">
+     *     <li> if childMergeOverride is set (non-null), use that value (true/false)</li>
+     *     <li> retrieve the 'combine.children' attribute on the dominant node, and try to match against
+     *          'append'...</li>
+     *     <li> if it matches 'append', then set mergeChildren == false...the recessive children will be appended as
+     *          siblings of the dominant children.</li>
+     *     <li> otherwise, use the default value for mergeChildren, which is true...this is the same as specifying
+     *         'combine.children' == 'merge' as an attribute on the dominant root node.</li>
+     *     </ol></li>
+     *   <li> Iterate through the recessive children, and:
+     *     <ol type="i">
+     *     <li> if mergeChildren == true and there is a corresponding dominant child (matched by element name),
+     *          merge the two.</li>
+     *     <li> otherwise, add the recessive child as a new child on the dominant root node.</li>
+     *     </ol></li>
+     *   </ol></li>
+     * </ol>
      */
     private static void mergeIntoXpp3Dom( Xpp3Dom dominant, Xpp3Dom recessive, Boolean childMergeOverride )
     {
@@ -333,17 +408,20 @@ public class Xpp3Dom
 
         if ( mergeSelf )
         {
-            if ( isEmpty( dominant.getValue() ) )
+            if ( isEmpty( dominant.getValue() ) && !isEmpty( recessive.getValue() ) )
             {
                 dominant.setValue( recessive.getValue() );
+                dominant.setInputLocation( recessive.getInputLocation() );
             }
 
-            String[] recessiveAttrs = recessive.getAttributeNames();
-            for ( String attr : recessiveAttrs )
+            if ( recessive.attributes != null )
             {
-                if ( isEmpty( dominant.getAttribute( attr ) ) )
+                for ( String attr : recessive.attributes.keySet() )
                 {
-                    dominant.setAttribute( attr, recessive.getAttribute( attr ) );
+                    if ( isEmpty( dominant.getAttribute( attr ) ) )
+                    {
+                        dominant.setAttribute( attr, recessive.getAttribute( attr ) );
+                    }
                 }
             }
 
@@ -387,12 +465,16 @@ public class Xpp3Dom
                 {
                     Map<String, Iterator<Xpp3Dom>> commonChildren = new HashMap<String, Iterator<Xpp3Dom>>();
 
-                    for ( String childName : recessive.childMap.keySet() )
+                    for ( Xpp3Dom recChild : recessive.childList )
                     {
-                        Xpp3Dom[] dominantChildren = dominant.getChildren( childName );
-                        if ( dominantChildren.length > 0 )
+                        if ( commonChildren.containsKey( recChild.name ) )
                         {
-                            commonChildren.put( childName, Arrays.asList( dominantChildren ).iterator() );
+                            continue;
+                        }
+                        List<Xpp3Dom> dominantChildren = dominant.getChildrenAsList( recChild.name );
+                        if ( dominantChildren.size() > 0 )
+                        {
+                            commonChildren.put( recChild.name, dominantChildren.iterator() );
                         }
                     }
 
