@@ -16,6 +16,13 @@ package org.codehaus.plexus.util;
  * limitations under the License.
  */
 
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+
 import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileInputStream;
@@ -29,6 +36,11 @@ import java.io.Writer;
 import java.net.URL;
 import java.util.Properties;
 
+import org.junit.Before;
+import org.junit.Rule;
+import org.junit.Test;
+import org.junit.rules.TestName;
+
 /**
  * This is used to test FileUtils for correctness.
  *
@@ -40,6 +52,9 @@ import java.util.Properties;
 public final class FileUtilsTest
     extends FileBasedTestCase
 {
+    @Rule
+    public TestName name = new TestName();
+
     // Test data
 
     /**
@@ -65,10 +80,8 @@ public final class FileUtilsTest
         testFile2Size = (int) testFile2.length();
     }
 
-    /**
-     * @see junit.framework.TestCase#setUp()
-     */
-    protected void setUp()
+    @Before
+    public void setUp()
         throws Exception
     {
         getTestDirectory().mkdirs();
@@ -82,6 +95,7 @@ public final class FileUtilsTest
 
     // byteCountToDisplaySize
 
+    @Test
     public void testByteCountToDisplaySize()
     {
         assertEquals( FileUtils.byteCountToDisplaySize( 0 ), "0 bytes" );
@@ -92,6 +106,7 @@ public final class FileUtilsTest
 
     // waitFor
 
+    @Test
     public void testWaitFor()
     {
         FileUtils.waitFor( "", -1 );
@@ -99,6 +114,7 @@ public final class FileUtilsTest
         FileUtils.waitFor( "", 2 );
     }
 
+    @Test
     public void testToFile()
         throws Exception
     {
@@ -108,6 +124,7 @@ public final class FileUtilsTest
         assertEquals( "name #%20?{}[]<>.txt", file.getName() );
     }
 
+    @Test
     public void testToFileBadProtocol()
         throws Exception
     {
@@ -116,6 +133,7 @@ public final class FileUtilsTest
         assertNull( file );
     }
 
+    @Test
     public void testToFileNull()
         throws Exception
     {
@@ -124,15 +142,16 @@ public final class FileUtilsTest
     }
 
     // Hacked to sanity by Trygve
+    @Test
     public void testToURLs()
         throws Exception
     {
-        File[] files = new File[]{ new File( "file1" ), new File( "file2" ), };
+        File[] files = new File[] { new File( "file1" ), new File( "file2" ), };
 
         URL[] urls = FileUtils.toURLs( files );
 
         assertEquals( "The length of the generated URL's is not equals to the length of files. " + "Was " + files.length
-                          + ", expected " + urls.length, files.length, urls.length );
+            + ", expected " + urls.length, files.length, urls.length );
 
         for ( int i = 0; i < urls.length; i++ )
         {
@@ -140,6 +159,7 @@ public final class FileUtilsTest
         }
     }
 
+    @Test
     public void testGetFilesFromExtension()
     {
         // TODO I'm not sure what is supposed to happen here
@@ -147,22 +167,20 @@ public final class FileUtilsTest
 
         // Non-existent files
         final String[] emptyFileNames =
-            FileUtils.getFilesFromExtension( getTestDirectory().getAbsolutePath(), new String[]{ "java" } );
+            FileUtils.getFilesFromExtension( getTestDirectory().getAbsolutePath(), new String[] { "java" } );
         assertTrue( emptyFileNames.length == 0 );
 
         // Existing files
         // TODO Figure out how to test this
         /*
-        final String[] fileNames =
-            FileUtils.getFilesFromExtension(
-                getClass().getResource("/java/util/").getFile(),
-                new String[] { "class" });
-        assertTrue(fileNames.length > 0);
-        */
+         * final String[] fileNames = FileUtils.getFilesFromExtension( getClass().getResource("/java/util/").getFile(),
+         * new String[] { "class" }); assertTrue(fileNames.length > 0);
+         */
     }
 
     // mkdir
 
+    @Test
     public void testMkdir()
     {
         final File dir = new File( getTestDirectory(), "testdir" );
@@ -187,11 +205,12 @@ public final class FileUtilsTest
 
     // contentEquals
 
+    @Test
     public void testContentEquals()
         throws Exception
     {
         // Non-existent files
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
         assertTrue( FileUtils.contentEquals( file, file ) );
 
         // TODO Should comparing 2 directories throw an Exception instead of returning false?
@@ -199,11 +218,11 @@ public final class FileUtilsTest
         assertTrue( !FileUtils.contentEquals( getTestDirectory(), getTestDirectory() ) );
 
         // Different files
-        final File objFile1 = new File( getTestDirectory(), getName() + ".object" );
+        final File objFile1 = new File( getTestDirectory(), name.getMethodName() + ".object" );
         objFile1.deleteOnExit();
         FileUtils.copyURLToFile( getClass().getResource( "/java/lang/Object.class" ), objFile1 );
 
-        final File objFile2 = new File( getTestDirectory(), getName() + ".collection" );
+        final File objFile2 = new File( getTestDirectory(), name.getMethodName() + ".collection" );
         objFile2.deleteOnExit();
         FileUtils.copyURLToFile( getClass().getResource( "/java/util/Collection.class" ), objFile2 );
 
@@ -216,27 +235,32 @@ public final class FileUtilsTest
 
     // removePath
 
+    @Test
     public void testRemovePath()
     {
-        final String fileName = FileUtils.removePath( new File( getTestDirectory(), getName() ).getAbsolutePath() );
-        assertEquals( getName(), fileName );
+        final String fileName =
+            FileUtils.removePath( new File( getTestDirectory(), name.getMethodName() ).getAbsolutePath() );
+        assertEquals( name.getMethodName(), fileName );
     }
 
     // getPath
 
+    @Test
     public void testGetPath()
     {
-        final String fileName = FileUtils.getPath( new File( getTestDirectory(), getName() ).getAbsolutePath() );
+        final String fileName =
+            FileUtils.getPath( new File( getTestDirectory(), name.getMethodName() ).getAbsolutePath() );
         assertEquals( getTestDirectory().getAbsolutePath(), fileName );
     }
 
     // copyURLToFile
 
+    @Test
     public void testCopyURLToFile()
         throws Exception
     {
         // Creates file
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
         file.deleteOnExit();
 
         // Loads resource
@@ -258,11 +282,12 @@ public final class FileUtilsTest
 
     // catPath
 
+    @Test
     public void testCatPath()
     {
         // TODO StringIndexOutOfBoundsException thrown if file doesn't contain slash.
         // Is this acceptable?
-        //assertEquals("", FileUtils.catPath("a", "b"));
+        // assertEquals("", FileUtils.catPath("a", "b"));
 
         assertEquals( "/a/c", FileUtils.catPath( "/a/b", "c" ) );
         assertEquals( "/a/d", FileUtils.catPath( "/a/b/c", "../d" ) );
@@ -270,6 +295,7 @@ public final class FileUtilsTest
 
     // forceMkdir
 
+    @Test
     public void testForceMkdir()
         throws Exception
     {
@@ -277,7 +303,7 @@ public final class FileUtilsTest
         FileUtils.forceMkdir( getTestDirectory() );
 
         // Creates test file
-        final File testFile = new File( getTestDirectory(), getName() );
+        final File testFile = new File( getTestDirectory(), name.getMethodName() );
         testFile.deleteOnExit();
         testFile.createNewFile();
         assertTrue( "Test file does not exist.", testFile.exists() );
@@ -316,10 +342,11 @@ public final class FileUtilsTest
 
     // sizeOfDirectory
 
+    @Test
     public void testSizeOfDirectory()
         throws Exception
     {
-        final File file = new File( getTestDirectory(), getName() );
+        final File file = new File( getTestDirectory(), name.getMethodName() );
 
         // Non-existent file
         try
@@ -361,6 +388,7 @@ public final class FileUtilsTest
     }
 
     // copyFile
+    @Test
     public void testCopyFile1()
         throws Exception
     {
@@ -370,6 +398,7 @@ public final class FileUtilsTest
         assertTrue( "Check Full copy", destination.length() == testFile1Size );
     }
 
+    @Test
     public void testCopyFile2()
         throws Exception
     {
@@ -380,10 +409,11 @@ public final class FileUtilsTest
     }
 
     /**
-     * ensure we create  directory tree for destination
+     * ensure we create directory tree for destination
      *
      * @throws Exception
      */
+    @Test
     public void testCopyFile3()
         throws Exception
     {
@@ -400,6 +430,7 @@ public final class FileUtilsTest
 
     // copyFileIfModified
 
+    @Test
     public void testCopyIfModifiedWhenSourceIsNewer()
         throws Exception
     {
@@ -422,6 +453,7 @@ public final class FileUtilsTest
                     FileUtils.copyFileIfModified( source, destination ) );
     }
 
+    @Test
     public void testCopyIfModifiedWhenSourceIsOlder()
         throws Exception
     {
@@ -431,19 +463,38 @@ public final class FileUtilsTest
         File source = new File( getTestDirectory() + "copy1.txt" );
         FileUtils.copyFile( testFile1, source );
 
-        // Make sure desintation is newer
+        // Make sure destination is newer
         reallySleep( 1000 );
 
         // Place destination
-        File desintation = new File( getTestDirectory(), "/temp/copy1.txt" );
-        FileUtils.copyFile( testFile1, desintation );
+        File destination = new File( getTestDirectory(), "/temp/copy1.txt" );
+        FileUtils.copyFile( testFile1, destination );
 
-        // Copy will occur when desintation is newer
-        assertFalse( "Source file should not have been copied.", FileUtils.copyFileIfModified( source, desintation ) );
+        // Copy will occur when destination is newer
+        assertFalse( "Source file should not have been copied.", FileUtils.copyFileIfModified( source, destination ) );
+    }
+
+    @Test
+    public void testCopyIfModifiedWhenSourceHasZeroDate()
+        throws Exception
+    {
+        FileUtils.forceMkdir( new File( getTestDirectory(), "temp" ) );
+
+        // Source modified on 1970-01-01T00:00Z
+        File source = new File( getTestDirectory(), "copy1.txt" );
+        FileUtils.copyFile( testFile1, source );
+        source.setLastModified( 0L );
+
+        // A non existing destination
+        File destination = new File( getTestDirectory(), "temp/copy1.txt" );
+
+        // Should copy the source to the non existing destination.
+        assertTrue( "Source file should have been copied.", FileUtils.copyFileIfModified( source, destination ) );
     }
 
     // forceDelete
 
+    @Test
     public void testForceDeleteAFile1()
         throws Exception
     {
@@ -454,6 +505,7 @@ public final class FileUtilsTest
         assertTrue( "Check No Exist", !destination.exists() );
     }
 
+    @Test
     public void testForceDeleteAFile2()
         throws Exception
     {
@@ -466,6 +518,7 @@ public final class FileUtilsTest
 
     // copyFileToDirectory
 
+    @Test
     public void testCopyFile1ToDir()
         throws Exception
     {
@@ -480,6 +533,7 @@ public final class FileUtilsTest
         assertTrue( "Check Full copy", destination.length() == testFile1Size );
     }
 
+    @Test
     public void testCopyFile2ToDir()
         throws Exception
     {
@@ -496,6 +550,7 @@ public final class FileUtilsTest
 
     // copyFileToDirectoryIfModified
 
+    @Test
     public void testCopyFile1ToDirIfModified()
         throws Exception
     {
@@ -521,6 +576,7 @@ public final class FileUtilsTest
         assertTrue( "Timestamp was changed", timestamp == target.lastModified() );
     }
 
+    @Test
     public void testCopyFile2ToDirIfModified()
         throws Exception
     {
@@ -548,6 +604,7 @@ public final class FileUtilsTest
 
     // forceDelete
 
+    @Test
     public void testForceDeleteDir()
         throws Exception
     {
@@ -557,6 +614,7 @@ public final class FileUtilsTest
 
     // resolveFile
 
+    @Test
     public void testResolveFileDotDot()
         throws Exception
     {
@@ -564,6 +622,7 @@ public final class FileUtilsTest
         assertEquals( "Check .. operator", file, getTestDirectory().getParentFile() );
     }
 
+    @Test
     public void testResolveFileDot()
         throws Exception
     {
@@ -573,17 +632,16 @@ public final class FileUtilsTest
 
     // normalize
 
+    @Test
     public void testNormalize()
         throws Exception
     {
-        final String[] src =
-            { "", "/", "///", "/foo", "/foo//", "/./", "/foo/./", "/foo/./bar", "/foo/../bar", "/foo/../bar/../baz",
-                "/foo/bar/../../baz", "/././", "/foo/./../bar", "/foo/.././bar/", "//foo//./bar", "/../",
-                "/foo/../../" };
+        final String[] src = { "", "/", "///", "/foo", "/foo//", "/./", "/foo/./", "/foo/./bar", "/foo/../bar",
+            "/foo/../bar/../baz", "/foo/bar/../../baz", "/././", "/foo/./../bar", "/foo/.././bar/", "//foo//./bar",
+            "/../", "/foo/../../" };
 
-        final String[] dest =
-            { "", "/", "/", "/foo", "/foo/", "/", "/foo/", "/foo/bar", "/bar", "/baz", "/baz", "/", "/bar", "/bar/",
-                "/foo/bar", null, null };
+        final String[] dest = { "", "/", "/", "/foo", "/foo/", "/", "/foo/", "/foo/bar", "/bar", "/baz", "/baz", "/",
+            "/bar", "/bar/", "/foo/bar", null, null };
 
         assertEquals( "Oops, test writer goofed", src.length, dest.length );
 
@@ -613,6 +671,7 @@ public final class FileUtilsTest
      * Test the FileUtils implementation.
      */
     // Used to exist as IOTestCase class
+    @Test
     public void testFileUtils()
         throws Exception
     {
@@ -622,7 +681,7 @@ public final class FileUtilsTest
         assertNotNull( path + " was not found.", url );
 
         String filename = url.getFile();
-        //The following line applies a fix for spaces in a path
+        // The following line applies a fix for spaces in a path
         filename = replaceAll( filename, "%20", " " );
         final String filename2 = "test2.txt";
 
@@ -650,6 +709,7 @@ public final class FileUtilsTest
 
     }
 
+    @Test
     public void testGetExtension()
     {
         final String[][] tests =
@@ -659,10 +719,11 @@ public final class FileUtilsTest
         for ( String[] test : tests )
         {
             assertEquals( test[1], FileUtils.getExtension( test[0] ) );
-            //assertEquals(tests[i][1], FileUtils.extension(tests[i][0]));
+            // assertEquals(tests[i][1], FileUtils.extension(tests[i][0]));
         }
     }
 
+    @Test
     public void testGetExtensionWithPaths()
     {
         // Since the utilities are based on the separator for the platform
@@ -678,10 +739,11 @@ public final class FileUtilsTest
         for ( String[] testsWithPath : testsWithPaths )
         {
             assertEquals( testsWithPath[1], FileUtils.getExtension( testsWithPath[0] ) );
-            //assertEquals(testsWithPaths[i][1], FileUtils.extension(testsWithPaths[i][0]));
+            // assertEquals(testsWithPaths[i][1], FileUtils.extension(testsWithPaths[i][0]));
         }
     }
 
+    @Test
     public void testRemoveExtension()
     {
         final String[][] tests = { { "filename.ext", "filename" }, { "first.second.third.ext", "first.second.third" },
@@ -690,37 +752,38 @@ public final class FileUtilsTest
         for ( String[] test : tests )
         {
             assertEquals( test[1], FileUtils.removeExtension( test[0] ) );
-            //assertEquals(tests[i][1], FileUtils.basename(tests[i][0]));
+            // assertEquals(tests[i][1], FileUtils.basename(tests[i][0]));
         }
     }
 
     /* TODO: Reenable this test */
+    @Test
     public void testRemoveExtensionWithPaths()
     {
         // Since the utilities are based on the separator for the platform
         // running the test, ensure we are using the right separator
         final String sep = File.separator;
-        final String[][] testsWithPaths =
-            { { sep + "tmp" + sep + "foo" + sep + "filename.ext", sep + "tmp" + sep + "foo" + sep + "filename" },
-                { "C:" + sep + "temp" + sep + "foo" + sep + "filename.ext",
-                    "C:" + sep + "temp" + sep + "foo" + sep + "filename" },
-                { sep + "tmp" + sep + "foo.bar" + sep + "filename.ext",
-                    sep + "tmp" + sep + "foo.bar" + sep + "filename" },
-                { "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename.ext",
-                    "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename" },
-                { sep + "tmp" + sep + "foo.bar" + sep + "README", sep + "tmp" + sep + "foo.bar" + sep + "README" },
-                { "C:" + sep + "temp" + sep + "foo.bar" + sep + "README",
-                    "C:" + sep + "temp" + sep + "foo.bar" + sep + "README" },
-                { ".." + sep + "filename.ext", ".." + sep + "filename" } };
+        final String[][] testsWithPaths = {
+            { sep + "tmp" + sep + "foo" + sep + "filename.ext", sep + "tmp" + sep + "foo" + sep + "filename" },
+            { "C:" + sep + "temp" + sep + "foo" + sep + "filename.ext",
+                "C:" + sep + "temp" + sep + "foo" + sep + "filename" },
+            { sep + "tmp" + sep + "foo.bar" + sep + "filename.ext", sep + "tmp" + sep + "foo.bar" + sep + "filename" },
+            { "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename.ext",
+                "C:" + sep + "temp" + sep + "foo.bar" + sep + "filename" },
+            { sep + "tmp" + sep + "foo.bar" + sep + "README", sep + "tmp" + sep + "foo.bar" + sep + "README" },
+            { "C:" + sep + "temp" + sep + "foo.bar" + sep + "README",
+                "C:" + sep + "temp" + sep + "foo.bar" + sep + "README" },
+            { ".." + sep + "filename.ext", ".." + sep + "filename" } };
 
         for ( String[] testsWithPath : testsWithPaths )
         {
             assertEquals( testsWithPath[1], FileUtils.removeExtension( testsWithPath[0] ) );
-            //assertEquals(testsWithPaths[i][1], FileUtils.basename(testsWithPaths[i][0]));
+            // assertEquals(testsWithPaths[i][1], FileUtils.basename(testsWithPaths[i][0]));
         }
     }
 
-    public void testCopyDirectoryStructureWithAEmptyDirectoryStruture()
+    @Test
+    public void testCopyDirectoryStructureWithAEmptyDirectoryStructure()
         throws Exception
     {
         File from = new File( getTestDirectory(), "from" );
@@ -736,6 +799,7 @@ public final class FileUtilsTest
         FileUtils.copyDirectoryStructure( from, to );
     }
 
+    @Test
     public void testCopyDirectoryStructureWithAPopulatedStructure()
         throws Exception
     {
@@ -795,6 +859,7 @@ public final class FileUtilsTest
         checkFile( f2_1, new File( to, "2/2_1/2_1.txt" ) );
     }
 
+    @Test
     public void testCopyDirectoryStructureIfModified()
         throws Exception
     {
@@ -874,6 +939,7 @@ public final class FileUtilsTest
 
     }
 
+    @Test
     public void testCopyDirectoryStructureToSelf()
         throws Exception
     {
@@ -915,6 +981,7 @@ public final class FileUtilsTest
         }
     }
 
+    @Test
     public void testFilteredFileCopy()
         throws Exception
     {
@@ -927,7 +994,7 @@ public final class FileUtilsTest
         filterProperties.setProperty( "s", "sample text" );
 
         // test ${token}
-        FileUtils.FilterWrapper[] wrappers1 = new FileUtils.FilterWrapper[]{ new FileUtils.FilterWrapper()
+        FileUtils.FilterWrapper[] wrappers1 = new FileUtils.FilterWrapper[] { new FileUtils.FilterWrapper()
         {
             public Reader getReader( Reader reader )
             {
@@ -946,6 +1013,7 @@ public final class FileUtilsTest
         compareFile.delete();
     }
 
+    @Test
     public void testFilteredWithoutFilterAndOlderFile()
         throws Exception
     {
@@ -975,7 +1043,7 @@ public final class FileUtilsTest
 
     }
 
-
+    @Test
     public void testFilteredWithoutFilterAndOlderFileAndOverwrite()
         throws Exception
     {
@@ -1005,6 +1073,7 @@ public final class FileUtilsTest
 
     }
 
+    @Test
     public void testFileRead()
         throws IOException
     {
@@ -1033,6 +1102,7 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    @Test
     public void testFileReadWithEncoding()
         throws IOException
     {
@@ -1057,6 +1127,7 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    @Test
     public void testFileAppend()
         throws IOException
     {
@@ -1081,6 +1152,7 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    @Test
     public void testFileAppendWithEncoding()
         throws IOException
     {
@@ -1106,6 +1178,7 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    @Test
     public void testFileWrite()
         throws IOException
     {
@@ -1118,6 +1191,7 @@ public final class FileUtilsTest
         testFile.delete();
     }
 
+    @Test
     public void testFileWriteWithEncoding()
         throws IOException
     {
@@ -1139,6 +1213,7 @@ public final class FileUtilsTest
      * @see <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6182812">Sun bug id=6182812</a>
      * @see <a href="http://bugs.sun.com/bugdatabase/view_bug.do?bug_id=6481955">Sun bug id=6481955</a>
      */
+    @Test
     public void testDeleteLongPathOnWindows()
         throws Exception
     {
@@ -1175,7 +1250,8 @@ public final class FileUtilsTest
         }
     }
 
-    //Test for bug PLXUTILS-10
+    // Test for bug PLXUTILS-10
+    @Test
     public void testCopyFileOnSameFile()
         throws IOException
     {
@@ -1192,6 +1268,7 @@ public final class FileUtilsTest
         assertTrue( theFile.length() > 0 );
     }
 
+    @Test
     public void testExtensions()
         throws Exception
     {
@@ -1211,6 +1288,7 @@ public final class FileUtilsTest
         }
     }
 
+    @Test
     public void testIsValidWindowsFileName()
         throws Exception
     {
@@ -1236,6 +1314,7 @@ public final class FileUtilsTest
         }
     }
 
+    @Test
     public void testDeleteDirectoryWithValidFileSymlink()
         throws Exception
     {
@@ -1257,6 +1336,7 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    @Test
     public void testDeleteDirectoryWithValidDirSymlink()
         throws Exception
     {
@@ -1278,6 +1358,7 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    @Test
     public void testDeleteDirectoryWithDanglingSymlink()
         throws Exception
     {
@@ -1298,6 +1379,7 @@ public final class FileUtilsTest
         assertTrue( "Failed to delete test directory", !getTestDirectory().exists() );
     }
 
+    @Test
     public void testcopyDirectoryLayoutWithExcludesIncludes()
         throws Exception
     {
@@ -1339,6 +1421,7 @@ public final class FileUtilsTest
      *
      * @throws Exception if any
      */
+    @Test
     public void testCreateTempFile()
         throws Exception
     {
